#
# cppunit.mk
#
# Rules for running CppUnit tests.
#
# The variables that are used in this file, but need to be defined outside
# of this file, are listed here.
#
# Variables that should be defined in the makefile that includes this file:
# - UNITTESTS - the names of the test programs that should be run
#


# the general idea behind the current make rules is pretending that there
# are "results" that are generated by each unit test, and we make the overall
# "test" target depend on those results.  Of course, since no results are
# actually created (currently) by the unit tests, the tests always get run
# when the user types "gmake runtest".  At some point, we expect that results
# will become available, and this model should change at that point.


# initialization
unitTestBinaries = $(addprefix $(bindir)/, $(notdir $(UNITTESTS)))
unitTestResults = $(subst $(bindir),$(workdir),$(addsuffix .result, $(unitTestBinaries)))

# rule to make (fake) results file from each unit test
$(unitTestResults) : $(workdir)/%.result : $(bindir)/%
	@echo "<**running unit test**> $(notdir $<)"
	$<

# add the (fake) unit test results to the global runtest target
runtest : $(unitTestResults)

# include the environment variables for cppunit
include SoftRelTools/arch_spec_cppunit.mk
