#!/usr/bin/perl

# cvs_diff: Work back through log file allowing user to do relative or absolute 
#           differences.

#  Contact:  N. West.

#  Arguments:-
#  =========

#  $ARGV[0]  The absolute or relative file spec to used.

#  Specification:-
#  =============

#  Loop back through log file listing each entry in turn and asking
#  user what type of comparison to carry out.

sub help;

use strict;

my $file_spec = $ARGV[0];

#    Check that file is defined, exists and is CVS/SVN managed.

if ( not $file_spec ) {
  print "\nPlease specify a file name\n";
  help();
}

if ( not -r $file_spec ) {
  print "\nCannot find $file_spec\n";
  help();
}

my $dir       = "./";
my $file_name = $file_spec;
if ( $file_spec =~ /(.*)\/(.*)/ ) {
  $dir       = $1;
  $file_name = $2;
}

my $mode;
my $revision_pattern;

if ( -d "$dir/CVS" ) { 
  $mode = "cvs";
  $revision_pattern = "^revision ([\\d.]+)";
}
elsif ( -d "$dir/.svn" ) {
  $mode = "svn";
  $revision_pattern = "^r([\\d.]+)";
}
else {
  print "\n$file_spec is not a CVS or SVN managed file\n";
  help();
}


#   Read CVS/SVN log file and find latest revision.

chdir $dir;

print "Reading log file ...";

my @log_lines     = ();
my $revision_head = "";

open(LOG, "$mode log $file_name 2> /dev/null |") or die "Cannot pipe $mode log $file_name\n";
while ( my $log_line =<LOG> ) {
  if ( $log_line =~ /$revision_pattern/ ) {
    push @log_lines,$log_line if  $mode eq "svn"; #SVN combines the revision line with the date and author.
    $revision_head = $1;
    last;
  }
}
$revision_head or die "Cannot find head revision\n";

print "Head revision is: $revision_head\n";

my $revision_cur  = $revision_head;
my $revision_pre  = "";

#  Loop backwards over log file listing out changes and asking user what
#  comparisions to make.

while ( my $log_line = <LOG> ) {

  if ( not $log_line =~ /^-{25,}$/ ) {
    push @log_lines,$log_line;
    next;
  }

  $log_line = <LOG>;
  $log_line =~ /$revision_pattern/;
  $revision_pre = $1;


  my $ans = "I";
  while ( 1 ) {
    if ( $ans eq "I" ) { 
      if ( $mode eq "svn" ) { system("svn diff -r $revision_pre:$revision_cur    $file_name") ; }
      else                  { system("cvs diff -r $revision_pre -r $revision_cur $file_name"); }
    }
    print "\n\nLog entry for $revision_cur:-\n\n @log_lines\n\n";
    print "Compare $revision_pre to:  F (current file) H (head - $revision_head) I (incremental - $revision_cur) S (skip - default) Q or X (exit): ";
    $ans = <STDIN>;
    chomp $ans;
    $ans = "S" if not $ans;
    $ans = "\U$ans";
    if ( $ans eq "F" ) {
      system("$mode diff -r $revision_pre $file_name");
    }
    if ( $ans eq "H" ) {
      if ( $mode eq "svn" ) { system("svn diff -r $revision_pre:$revision_head    $file_name"); }
      else                  { system("cvs diff -r $revision_pre -r $revision_head $file_name"); }
    }
    if ( $ans eq "I" ) {
      next;
    }
    if ( $ans eq "S" ) {
      $ans = "I";
      last;
    }
    if ( $ans eq "X"or $ans eq "Q" ) {
      exit 0;
    }
  }
  $revision_cur = $revision_pre;
  @log_lines = ();
  push @log_lines,$log_line if  $mode eq "svn"; #SVN combines the revision line with the date and author.
  print "\n\n";
}

print "\n\n@log_lines\n\n";

close(LOG);

exit 0;

sub help {

  print "\ncvs_diff is a simple utility to compare different versions of a CVS or SVN\n";
  print "managed file.\n";
  print "\n";
  print " invocation:  cvs_diff <file-space>\n";
  print "\n";
  print "The utility reads the log file and prints the last entry, along with\n";
  print "the incremental difference to the file itself.\n";
  print "\n";
  print "After printing an entry the user is offered the following choices:-\n";
  print "\n";
  print " F  Compare this revision to the current file.\n";
  print " H  Compare this revision to the HEAD revision.\n";
  print " I  Compare this revision incrementally i.e. to the following revision.\n";
  print " S  [Default]: skip - to previous entry in the log file.\n";
  print " X  (or Q) Exit.\n";
  print "\n";
  print "So simply repeatedly pressing RETURN will step backwards though the development\n";
  print "of the file showing its changes and associated log entries.\n\n";
  exit 0;
}
