#!/bin/bash
#

# ups_product_tag.sh <new ups version> 

usage()
{
   echo "USAGE: `basename ${0}` <ups version>"
   echo "Please run from the ups directory of the repository"
}


# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

ups_version=${1}

if [ -z ${ups_version} ]
then 
    usage
    exit 1
fi

# -------------------------------------------------------------------
# need to edit product_deps, build_novaddt.sh and bootstrap.sh
# to have the correct product version
# also need to tag the repository
# -------------------------------------------------------------------

# first edit the product_deps file - only need to change the parent version line
# then the bootstrap.sh script and build_novadaq.sh scripts
sed -i~ "s/parent novaddt devel/parent novaddt ${ups_version}/" product_deps
sed -i~ "s/pkgver=devel/pkgver=${ups_version}/"                 bootstrap.sh
sed -i~ 's/trunk/tags\/\$pkgver/'                               bootstrap.sh
sed -i~ "s/pkgver=devel/pkgver=${ups_version}/"                 build_novaddt.sh

# now commit these changes to the repository
svn commit -m"preparing for ups version tag $ups_version"

# copy the trunk to the tag
svn cp svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt/novaddt.svn/trunk \
svn+ssh://p-novaddt@cdcvs.fnal.gov/cvs/projects/novaddt/novaddt.svn/tags/${ups_version} \
-m"create tag for ups version ${ups_version}"

# the tag is good to go, so now revert the trunk to use devel instead of ${ups_version}
sed -i~ "s/parent novaddt ${ups_version}/parent novaddt devel/" product_deps
sed -i~ 's/tags\/\$pkgver/trunk/'                               bootstrap.sh
sed -i~ "s/pkgver=${ups_version}/pkgver=devel/"                 bootstrap.sh
sed -i~ "s/pkgver=${ups_version}/pkgver=devel/"                 build_novaddt.sh

svn commit -m'reset the scripts in the trunk to setup devel as the ups version'


exit 0
